EnumPropertySchema class final

Inheritance

Constructors

EnumPropertySchema({String? name, String? description, bool? isRequired, required List<String> options})
const

Properties

description String?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
isRequired bool?
finalinherited
jsonType String
no setteroverride
name String?
finalinherited
options List<String>
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited